Uses of Class org.openqa.selenium.server.browserlaunchers.MacProxyManager (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

## Uses of Class
org.openqa.selenium.server.browserlaunchers.MacProxyManager

Packages that use MacProxyManager
org.openqa.selenium.server.browserlaunchers | Provides classes to launch and kill browsers.

Uses of MacProxyManager in org.openqa.selenium.server.browserlaunchers

Fields in org.openqa.selenium.server.browserlaunchers declared as MacProxyManager
`protected MacProxyManager` | `SafariCustomProfileLauncher.mpm`

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

Copyright © 2009. All Rights Reserved.